SQL DDL
=======

Overview
--------

Docs
----

Command Line
^^^^^^^^^^^^

.. currentmodule:: linkml.generators.sqlddlgen

.. click:: linkml.generators.sqlddlgen:cli
    :prog: gen-sqlddl
    :nested: short

Code
^^^^

                   
.. autoclass:: SqlddlGenerator
    :members: serialize
